/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useRef } from "react";
//material ui components
import TextField from "@material-ui/core/TextField";
import MenuItem from "@material-ui/core/MenuItem";
import FormGroup from "@material-ui/core/FormGroup";
import FormControlLabel from "@material-ui/core/FormControlLabel";
import CircularProgress from "@material-ui/core/CircularProgress";
import Checkbox from "@material-ui/core/Checkbox";
import SendRoundedIcon from "@material-ui/icons/SendRounded";
import Button from "@material-ui/core/Button";
import { makeStyles } from '@material-ui/core/styles';
import Chip from '@material-ui/core/Chip';
//imports from local files
import SnackBar from "../../../../Components/SnackbarComponent";
import { postRequest } from '../../../../Components/HelperFunctions/getAxiosConfig'
import ClassicEditor from "@ckeditor/ckeditor5-build-classic"
import { CKEditor } from '@ckeditor/ckeditor5-react';

let sendToAll = false;

const useStyles = makeStyles((theme) => ({
    root: {
        display: 'flex',
        justifyContent: 'center',
        flexWrap: 'wrap',
        listStyle: 'none',
        padding: theme.spacing(0.5),
        margin: 0,
    },
    chip: {
        margin: theme.spacing(0.5),
    },
}));

const EmailInputs = (props) => {
    const classes = useStyles();
    const [option, setOption] = useState("Todos os usuários"); //labels of the text field 'to'
    const [index, setIndex] = useState(0); //Used to display something above the text field 'to' depending on what the user clicks

    // Capture th text insert by the user in the fields
    const [emails, setEmails] = useState(props.email === "none" ? "" : props.email);
    const [emailsAdress, setEmailsAdress] = useState([]);
    const [subject, setSubject] = useState("");
    const [message, setMessage] = useState("");

    const [isSending, setIsSending] = useState(false);

    //Handle snack bar
    const [snackInfo, setSnackInfo] = useState({
        message: "",
        icon: "",
        open: false,
        color: "",
    });

    //Controls the state of error in the textfields
    const [errorInEmails, setErrorInEmail] = useState({
        error: false,
        arroba: false,
        message: "",
    });
    const [errorInSubject, setErrorInSubject] = useState({
        error: false,
        message: "",
    });

    const options = [
        {
            value: "All",
            label: "Todos os usuários",
        },
        {
            value: "Roles",
            label: "Roles/Permissões específicas",
        },
        {
            value: "Emails",
            label: "1 ou mais emails",
        },
    ];

    //Roles of permissions
    const [roles, setRoles] = useState([
        {
            label: "Editor",
            value: 7,
            isChecked: false,
        },
        {
            label: "Admin",
            value: 3,
            isChecked: false,
        },
        {
            label: "Curador",
            value: 4,
            isChecked: false,
        },
        {
            label: "Professor",
            value: 1,
            isChecked: false,
        },
        {
            label: "Submetedor",
            value: 8,
            isChecked: false,
        },
        {
            label: "Aluno",
            value: 2,
            isChecked: false,
        },
        {
            label: "Moderador",
            value: 5,
            isChecked: false,
        },
        {
            label: "Parceiro",
            value: 9,
            isChecked: false,
        },
        {
            label: "Supervisor",
            value: 6,
            isChecked: false,
        },
        {
            label: "Publicador",
            value: 10,
            isChecked: false,
        },
    ]);

    const handleChange = (e) => {
        const value = e.target.value;
        if (value === "All") {
            sendToAll = true;
        } else {
            sendToAll = false;
        }
        setOption(value);
    };

    const handleChangeCheckBox = (i) => {
        const currState = [...roles];
        currState[i].isChecked = !currState[i].isChecked;
        setRoles(currState);
    };

    const EmailsHandler = (e) => {
        if (errorInEmails.error)
            setErrorInEmail({
                error: false,
                message: "",
            });
        setEmails(e.target.value)
    };

    const SubjectHandler = (e) => {
        if (errorInSubject.error) {
            setErrorInSubject({
                error: false,
                message: "",
            });
        }
        setSubject(e.target.value);
    };

    const OnKeyPressHandler = (key) => {
        if (key === 13) {
            if (!isEmpty(emails)) {
                if (emails.includes("@")) {
                    const arr = [...emailsAdress];
                    arr.push(emails);
                    setEmails("");
                    setEmailsAdress(arr);
                } else {
                    setErrorInEmail({
                        error: true,
                        message: "Esse email não contém o caractere @",
                        arroba: false,
                    });
                }
            } else {
                setErrorInEmail({
                    error: true,
                    message: "Esse campo precisa ser preenchido",
                    arroba: false,
                });
            }
        }
    };

    //Delete emails adress from the list to be sent a message
    const HandleDelete = (i) => {
        const copyEmail = [...emailsAdress];
        copyEmail.splice(i, 1);
        setEmailsAdress(copyEmail);
    };

    const isEmpty = (text) => {
        return text.length === 0 ? true : false;
    };

    // Handle snack infos
    const HandleSnack = (message, state, icon, color) => {
        setSnackInfo({
            message: message,
            icon: icon,
            open: state,
            color: color,
        });
    };

    const CleanFields = () => {
        setMessage("");
        setSubject("");
        setEmailsAdress([]);
    };

    const submitRequest = async () => {
        // setIsSending(true);
        const rolesArr = [];
        roles.map((role) => {
            if (role.isChecked)
                rolesArr.push(role.value)
        })
        console.log(rolesArr)
        console.log(sendToAll)
        const api = `/email`;
        const body = {
            "email": {
                "all_users": sendToAll,
                "subject": subject,
                "body": message,
                "emails": emailsAdress,
                "roles": rolesArr,
            },
        };
        postRequest(
            api,
            body,
            (data, header) => {
                HandleSnack(
                    "O email foi enviado com sucesso",
                    true,
                    "success",
                    "#228B22"
                );
                setIsSending(false);
                CleanFields();
            },
            (error) => {
                HandleSnack("Ocorreu algum erro", true, "warning", "#FA8072");
                setIsSending(false);
                CleanFields();
            }
        )
    };

    return (
        <div
            style={{
                width: "100%",
                display: "flex",
                flexDirection: "column",
                justifyContent: "space-around",
            }}
        >
            <form
                style={{
                    flex: 1,
                    display: "flex",
                    flexDirection: "column",
                }}
            >
                <SnackBar
                    severity={snackInfo.icon}
                    text={snackInfo.message}
                    snackbarOpen={snackInfo.open}
                    color={snackInfo.color}
                    handleClose={() =>
                        setSnackInfo({
                            message: "",
                            icon: "",
                            open: false,
                            color: "",
                        })
                    }
                />

                <TextField
                    id="outlined-input"
                    label="De *"
                    defaultValue="integrada.contato@mec.gov.br"
                    variant="outlined"
                    disabled={true}
                />
                <div style={{ height: "1em" }} />

                <TextField
                    select
                    label="Para *"
                    value={option ? option : ""}
                    onChange={handleChange}
                    helperText="Por favor, selecione uma das opções"
                >
                    {options.map((option, index) => (
                        <MenuItem
                            onClick={() => setIndex(index)}
                            key={option.value}
                            value={option.value}
                        >
                            {option.label}
                        </MenuItem>
                    ))}
                </TextField>
                <div style={{ height: "1em" }} />

                {index === 0 ? null : index === 1 ? (
                    <FormGroup style={{ marginBottom: "1em" }}>
                        {roles.map((role, index) => (
                            <FormControlLabel
                                key={index}
                                control={
                                    <Checkbox
                                        checked={role.isChecked}
                                        onChange={() => handleChangeCheckBox(index)}
                                        name={role.label}
                                        color="primary"
                                    />
                                }
                                label={role.label}
                            />
                        ))}
                    </FormGroup>
                ) : (
                        <>
                            <div
                                style={{
                                    display: "flex",
                                    flexDirection: "row",
                                    flexWrap: "wrap",
                                    justifyContent: "Space-between",
                                    marginBottom: "1em"
                                }}
                            >
                                {emailsAdress.map((email, index) => (
                                    <li key={index} style={{ listStyleType: "none", marginBottom: "0.5em" }}>
                                        <Chip
                                            label={email}
                                            onDelete={() => HandleDelete(index)}
                                            classes={classes.chip}
                                        />
                                    </li>
                                ))}
                            </div>

                            <TextField
                                id="outlined-input"
                                label="Emails"
                                rows={1}
                                error={errorInEmails.error}
                                helperText={errorInEmails.message}
                                value={emails}
                                onKeyPress={(key) => OnKeyPressHandler(key.which)}
                                onChange={EmailsHandler}
                                // onBlur={ShowEmails}
                                placeholder="Digite um email por vez e pressione Enter"
                                variant="outlined"
                                style={{ marginBottom: "1em" }}
                            />
                        </>
                    )}

                <TextField
                    id="outlined-input"
                    label="Assunto"
                    value={subject}
                    error={errorInSubject.error}
                    helperText={errorInSubject.message}
                    placeholder="Digite o assunto do email"
                    onChange={SubjectHandler}
                    variant="outlined"
                />
            </form>

            <div style={{ height: "1em" }} />

            <div style={{ flex: 1 }}>
                <CKEditor
                    editor={ClassicEditor}
                    data={message}
                    onBlur={(event, editor) => {
                        const data = editor.getData();
                        setMessage(data)
                    }}
                />
            </div>

            <div style={{ fontSize: 14 }}>
                * Se você deseja enviar foto da sua máquina, é preciso <a href="mailto:name@email.com">Clicar aqui</a>
            </div>

            <div style={{ marginTop: 18 }}>
                <Button
                    onClick={() => {
                        submitRequest();
                    }}
                    variant="contained"
                    disabled={isSending}
                    color="primary"
                    startIcon={<SendRoundedIcon />}
                >
                    {isSending ? <CircularProgress /> : "Enviar"}
                </Button>
            </div>
        </div>
    );
};

export default EmailInputs;
